==> deepin-update-ui_1.0.12.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_bo.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="bo">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>རྒྱུད་ཁོངས་སུ་ཕྱིར་ལོག་བྱེད་བཞིན་ཡོད་པས། ཏོག་ཙམ་སྒུག་རོགས། </translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>རྒྱུད་ཁོངས་སུ་ཕྱིར་ལོག་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>བསྐྱར་སློང་།</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>རྒྱུད་ཁོངས་གསར་སྒྱུར་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>གསར་སྒྱུར་བྱེད་མཚམས་ཆད་པས། ཐེངས་འདིའི་རྒྱུད་ཁོངས་གསར་སྒྱུར་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>dpkgནོར་འཁྲུལ་བྱུང་སྟབས། ཐེངས་འདིའི་རྒྱུད་ཁོངས་གསར་སྒྱུར་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>སྡུད་སྡེར་གྱི་བར་སྟོང་མི་འདང་བས། ཐེངས་འདིའི་རྒྱུད་ཁོངས་གསར་སྒྱུར་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>རྒྱུད་ཁོངས་%2སྔོན་གྱི་%1ལ་འགྱུར་རྒྱུར་ཁྱོད་ཀྱིས་གཏན་ཁེལ་ལམ།</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>འདོར་བ་མ་ཟད་བསྐྱར་སློང་བྱེད།</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>གཏན་ཁེལ། </translation>
    </message>
</context>
</TS>

==> deepin-update-ui_1.0.38.1.tar.xz: BUILD/src/dde-abrecovery/translations/dde-rollback_bo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bo">
<context>
    <name>BackgroundWidget</name>
    <message>
        <source>Rolling back the system, please wait...</source>
        <translation>རྒྱུད་ཁོངས་སུ་ཕྱིར་ལོག་བྱེད་བཞིན་ཡོད་པས། ཏོག་ཙམ་སྒུག་རོགས། </translation>
    </message>
</context>
<context>
    <name>RecoveryWidget</name>
    <message>
        <source>Rollback failed.</source>
        <translation>རྒྱུད་ཁོངས་སུ་ཕྱིར་ལོག་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>བསྐྱར་སློང་།</translation>
    </message>
    <message>
        <source>Updates failed.</source>
        <translation>རྒྱུད་ཁོངས་གསར་སྒྱུར་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Updates failed: it was interrupted.</source>
        <translation>གསར་སྒྱུར་བྱེད་མཚམས་ཆད་པས། ཐེངས་འདིའི་རྒྱུད་ཁོངས་གསར་སྒྱུར་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Updates failed: DPKG error.</source>
        <translation>dpkgནོར་འཁྲུལ་བྱུང་སྟབས། ཐེངས་འདིའི་རྒྱུད་ཁོངས་གསར་སྒྱུར་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Updates failed: insufficient disk space.</source>
        <translation>སྡུད་སྡེར་གྱི་བར་སྟོང་མི་འདང་བས། ཐེངས་འདིའི་རྒྱུད་ཁོངས་གསར་སྒྱུར་བྱེད་མ་ཐུབ།</translation>
    </message>
    <message>
        <source>Are you sure you want to roll back to %1 backed up on %2?</source>
        <translation>རྒྱུད་ཁོངས་%2སྔོན་གྱི་%1ལ་འགྱུར་རྒྱུར་ཁྱོད་ཀྱིས་གཏན་ཁེལ་ལམ།</translation>
    </message>
    <message>
        <source>Cancel and Reboot</source>
        <translation>འདོར་བ་མ་ཟད་བསྐྱར་སློང་བྱེད།</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>གཏན་ཁེལ། </translation>
    </message>
</context>
</TS>
